@@ -1,3 +1,6 @@
+import shutil, os
+if not os.path.exists(os.path.join(os.getcwd(),"assets")):
+    shutil.copytree(os.path.join(os.path.dirname(os.path.realpath(__file__)),"templates/assets"),os.path.join(os.getcwd(),"assets"))
 def main():
     import sys
     from cvdastwrapper import fuzzallspecs
