@@ -20,8 +20,9 @@ from cvdastwrapper.runconfig import apispeclist, fuzzattacklist
 from cvdastwrapper.html_content_gen import generate_test_report
 from jinja2 import Environment, FileSystemLoader
 from cvdastwrapper import reportutil
+from cvdastwrapper import apispecs
 
-resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
+resultrootn = runconfig.dresultdir + "\\" + runconfig.dperadir + "\\"
 ainfofname = runconfig.dainfofname
 global data
 data = {"test_spec_insights": {}, "summary": {}, "metadata_spec": []}
@@ -289,7 +290,7 @@ def iterateallspecs(inspeclist=[], inattacklist=[]):
 
     inputfilenum = 0
     for spec in thespeclist:
-        print(spec)
+        #print(resultrootn+spec, " resultrootn+spec")
         spec = spec.lower()   # important, cannonical form of spec all lower case
         if not os.path.exists(resultrootn+spec):
             print("-- Failed to generate summary report: %s does not exist. " %
@@ -320,8 +321,9 @@ def iterateallspecs(inspeclist=[], inattacklist=[]):
             "all_spec_apis": set(),
             "all_failed_apis": set(),
         }
+        #print(theattacklist, "THEATTACXKLIST")
         for a in theattacklist:
-            print(a)
+            #print(a, "Inattacklist")
             arname = a
             if arname.find("/"):
                 arname = arname.replace("/", "_")
@@ -363,13 +365,16 @@ def iterateallspecs(inspeclist=[], inattacklist=[]):
             apilist_pri_report[spec] = spec_report
             generate_test_report(apilist_pri_report, spec, tests)
 
-        print("Report for Spec: {} is {}".format(spec, apilist_pri_report))
+        #print("Report for Spec: {} is {}".format(spec, apilist_pri_report))
     return apilist_pri_report
 
 
 def get_most_frequent_attack(report_json):
     attack_category_json = report_json['attack_category']
+    if not attack_category_json:
+        return {}
     sorted(attack_category_json.items(), key=lambda item: 'count')
+    #print(attack_category_json)    
     res = list(attack_category_json.keys())[0]
     val = attack_category_json[res]
     freq_string = res + " - " + str(val['count']) + \
@@ -402,7 +407,9 @@ def get_attack_catogery_count(report_json):
 
 def get_spec_details(report_json):
     res = {}
-    api_count = 0
+    api_count = 0    
+    apispeclist = apispecs.apispeclist
+    #print(apispeclist, "APISPECLIST")
     for spec in apispeclist:
         res[spec] = report_json[spec]
         pri = report_json[spec]['apis_by_priority']
@@ -435,17 +442,19 @@ def generate_html_report(result_report_json, filename):
     env = Environment(loader=FileSystemLoader(templates_dir))
     # print(templates_dir, root) - root is project root directory that is report_gen
     template = env.get_template('index.html')
-
+    #print(result_report_json, "RRRRRRRRRR")
     frequent_attack = get_most_frequent_attack(result_report_json)
     category_counts = get_attack_catogery_count(result_report_json)
     spec_details = get_spec_details(result_report_json)
-
+    #print(spec_details, "_____+++++++")
+    #print(runconfig.fuzzattacklist, "oooooo")
     with open(filename, 'w') as fh:
         fh.write(template.render(
-            num_spec_files=len(apispeclist),
+            num_spec_files=len(apispecs.apispeclist),
             num_total_apis=len(result_report_json.get('all_apis')),
             num_dst_hosts=1,  # TODO: len(runconfig.dhostname)
             num_attack_categ=len(runconfig.fuzzattacklist),
+            
 
             total_attack_vectors=result_report_json.get('total_count'),
             total_critical_av_count=result_report_json.get('critical_count'),
