@@ -29,7 +29,7 @@ from datetime import datetime
 #  shoutl be added
 #
 def processFnames(inargv, postfix, defaultf, defaultt):
-    print(inargv, postfix, defaultf, defaultt, "----")
+    #print(inargv, postfix, defaultf, defaultt, "----")
     if len(inargv) > 2:
         if inargv[2].endswith(postfix):
             return (inargv[2], False, False)
@@ -67,16 +67,14 @@ def main():
         htmlfname = htmlfname+"-"+tstamp+".html"
     if addcsvtstamp:
         csvfname  = csvfname+"-"+tstamp+".csv"
-    if not regen:    
-        runconfig.dhostname = input("Enter the Destination Host To Test : ")         
-
+    
     reportutil.init()
 
     print("\n Testing APIs and generating html report in %s and csv report in %s \n" % (htmlfname, csvfname))
     ra = ""
     hs = "<html>\n<head>\n<style>\ntable, th, td {\n  border: 1px dotted black;\n border-collapse: collapse}</style>\n<title>API Test Report Summary</title></head><body><br>\n"
     print ("\n------- Starting API Tests: Testing all APIs in a spec one fuzz attack type at a time. \n")
-    print(regen, runconfig.apispeclist, fuzzattacklist, dir(runconfig))
+    #print(regen, runconfig.apispeclist, fuzzattacklist, dir(runconfig))
     ra = perattackcall(regen, runconfig.apispeclist, fuzzattacklist)
     
     (rsum, detail, rfailed, rskipped) = sumreport.sumperattack(csvfname, runconfig.apispeclist, fuzzattacklist)
@@ -99,9 +97,9 @@ def main():
     f.write("\n\n</body></html>")
     f.close()
 
-    #result_report = iterateallspecs(runconfig.apispeclist, runconfig.fuzzattacklist)
+    result_report = iterateallspecs(runconfig.apispeclist, runconfig.fuzzattacklist)
     #print("-----+++",result_report)
-    #generate_html_report(result_report, "report_summary_"+str(time.time())+".html")
+    generate_html_report(result_report, "report_summary_"+str(time.time())+".html")
     
 if __name__ == "__main__":
     # execute only if run as a script
